@@ -63,14 +63,14 @@ impl ArgsKwargs {
     }
 }
 
-static UNDEFINED_CELL: GILOnceCell<Py<UndefinedType>> = GILOnceCell::new();
+static UNDEFINED_CELL: GILOnceCell<Py<PydanticUndefinedType>> = GILOnceCell::new();
 
 #[pyclass(module = "pydantic_core._pydantic_core", frozen)]
 #[derive(Debug)]
-pub struct UndefinedType {}
+pub struct PydanticUndefinedType {}
 
 #[pymethods]
-impl UndefinedType {
+impl PydanticUndefinedType {
     #[new]
     pub fn py_new(_py: Python) -> PyResult<Self> {
         Err(PyNotImplementedError::new_err(
@@ -81,7 +81,7 @@ impl UndefinedType {
     #[staticmethod]
     pub fn new(py: Python) -> Py<Self> {
         UNDEFINED_CELL
-            .get_or_init(py, || UndefinedType {}.into_py(py).extract(py).unwrap())
+            .get_or_init(py, || PydanticUndefinedType {}.into_py(py).extract(py).unwrap())
             .clone()
     }
 
@@ -93,6 +93,7 @@ impl UndefinedType {
         UNDEFINED_CELL.get(py).unwrap().clone()
     }
 
+    #[pyo3(signature = (_memo, /))]
     fn __deepcopy__(&self, py: Python, _memo: &PyAny) -> Py<Self> {
         self.__copy__(py)
     }
@@ -102,8 +103,8 @@ impl UndefinedType {
     }
 }
 
-impl UndefinedType {
+impl PydanticUndefinedType {
     pub fn py_undefined() -> Py<Self> {
-        Python::with_gil(UndefinedType::new)
+        Python::with_gil(PydanticUndefinedType::new)
     }
 }
