@@ -95,6 +95,7 @@ impl SchemaError {
             }
             ValError::InternalErr(err) => err,
             ValError::Omit => Self::new_err("Unexpected Omit error."),
+            ValError::UseDefault => Self::new_err("Unexpected UseDefault error."),
         }
     }
 
@@ -129,7 +130,7 @@ impl SchemaError {
 
     fn __str__(&self, py: Python) -> String {
         match &self.0 {
-            SchemaErrorEnum::Message(message) => message.to_owned(),
+            SchemaErrorEnum::Message(message) => message.clone(),
             SchemaErrorEnum::ValidationError(error) => error.display(py, Some("Invalid Schema:"), false),
         }
     }
