@@ -8,6 +8,7 @@ use pyo3::once_cell::GILOnceCell;
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyList};
 
+use crate::input::Int;
 use crate::tools::{extract_i64, py_err, py_error_type};
 use strum::{Display, EnumMessage, IntoEnumIterator};
 use strum_macros::EnumIter;
@@ -20,15 +21,14 @@ pub enum ErrorMode {
     Json,
 }
 
-impl TryFrom<Option<&str>> for ErrorMode {
+impl TryFrom<&str> for ErrorMode {
     type Error = PyErr;
 
-    fn try_from(error_mode: Option<&str>) -> PyResult<Self> {
+    fn try_from(error_mode: &str) -> PyResult<Self> {
         match error_mode {
-            None => Ok(Self::Python),
-            Some("python") => Ok(Self::Python),
-            Some("json") => Ok(Self::Json),
-            Some(s) => py_err!(PyValueError; "Invalid error mode: {}", s),
+            "python" => Ok(Self::Python),
+            "json" => Ok(Self::Json),
+            s => py_err!(PyValueError; "Invalid error mode: {}", s),
         }
     }
 }
@@ -82,7 +82,6 @@ pub enum ErrorType {
     RecursionLoop,
     // ---------------------
     // typed dict specific errors
-    DictAttributesType,
     Missing,
     FrozenField,
     FrozenInstance,
@@ -93,14 +92,21 @@ pub enum ErrorType {
     },
     // ---------------------
     // model class specific errors
-    ModelClassType {
+    ModelType {
+        class_name: String,
+    },
+    ModelAttributesType,
+    // ---------------------
+    // dataclass errors (we don't talk about ArgsKwargs here for simplicity)
+    DataclassType {
+        class_name: String,
+    },
+    DataclassExactType {
         class_name: String,
     },
     // ---------------------
     // None errors
     NoneRequired,
-    // boolean errors
-    Bool,
     // ---------------------
     // generic comparison errors - used for all inequality comparisons except int and float which have their
     // own type, bounds arguments are Strings so they can be created from any type
@@ -282,11 +288,6 @@ pub enum ErrorType {
     MissingPositionalOnlyArgument,
     MultipleArgumentValues,
     // ---------------------
-    // dataclass errors (we don't talk about ArgsKwargs here for simplicity)
-    DataclassType {
-        dataclass_name: String,
-    },
-    // ---------------------
     // URL errors
     UrlType,
     UrlParsing {
@@ -366,8 +367,8 @@ macro_rules! extract_context {
     }};
 }
 
-fn plural_s(value: &usize) -> &'static str {
-    if *value == 1 {
+fn plural_s(value: usize) -> &'static str {
+    if value == 1 {
         ""
     } else {
         "s"
@@ -389,7 +390,9 @@ impl ErrorType {
             Self::NoSuchAttribute { .. } => extract_context!(NoSuchAttribute, ctx, attribute: String),
             Self::JsonInvalid { .. } => extract_context!(JsonInvalid, ctx, error: String),
             Self::GetAttributeError { .. } => extract_context!(GetAttributeError, ctx, error: String),
-            Self::ModelClassType { .. } => extract_context!(ModelClassType, ctx, class_name: String),
+            Self::ModelType { .. } => extract_context!(ModelType, ctx, class_name: String),
+            Self::DataclassType { .. } => extract_context!(DataclassType, ctx, class_name: String),
+            Self::DataclassExactType { .. } => extract_context!(DataclassExactType, ctx, class_name: String),
             Self::GreaterThan { .. } => extract_context!(GreaterThan, ctx, gt: Number),
             Self::GreaterThanEqual { .. } => extract_context!(GreaterThanEqual, ctx, ge: Number),
             Self::LessThan { .. } => extract_context!(LessThan, ctx, lt: Number),
@@ -438,7 +441,6 @@ impl ErrorType {
                 expected_tags: String
             ),
             Self::UnionTagNotFound { .. } => extract_context!(UnionTagNotFound, ctx, discriminator: String),
-            Self::DataclassType { .. } => extract_context!(DataclassType, ctx, dataclass_name: String),
             Self::UrlParsing { .. } => extract_context!(UrlParsing, ctx, error: String),
             Self::UrlSyntaxViolation { .. } => extract_context!(Cow::Owned, UrlSyntaxViolation, ctx, error: String),
             Self::UrlTooLong { .. } => extract_context!(UrlTooLong, ctx, max_length: usize),
@@ -463,16 +465,17 @@ impl ErrorType {
             Self::JsonInvalid {..} => "Invalid JSON: {error}",
             Self::JsonType => "JSON input should be string, bytes or bytearray",
             Self::RecursionLoop => "Recursion error - cyclic reference detected",
-            Self::DictAttributesType => "Input should be a valid dictionary or instance to extract fields from",
             Self::Missing => "Field required",
             Self::FrozenField => "Field is frozen",
             Self::FrozenInstance => "Instance is frozen",
             Self::ExtraForbidden => "Extra inputs are not permitted",
             Self::InvalidKey => "Keys should be strings",
             Self::GetAttributeError {..} => "Error extracting attribute: {error}",
-            Self::ModelClassType {..} => "Input should be an instance of {class_name}",
+            Self::ModelType {..} => "Input should be a valid dictionary or instance of {class_name}",
+            Self::ModelAttributesType => "Input should be a valid dictionary or object to extract fields from",
+            Self::DataclassType {..} => "Input should be a dictionary or an instance of {class_name}",
+            Self::DataclassExactType {..} => "Input should be an instance of {class_name}",
             Self::NoneRequired => "Input should be None",
-            Self::Bool => "Input should be a valid boolean",
             Self::GreaterThan {..} => "Input should be greater than {gt}",
             Self::GreaterThanEqual {..} => "Input should be greater than or equal to {ge}",
             Self::LessThan {..} => "Input should be less than {lt}",
@@ -501,7 +504,7 @@ impl ErrorType {
             Self::IntFromFloat => "Input should be a valid integer, got a number with a fractional part",
             Self::IntParsingSize => "Unable to parse input string as an integer, exceeded maximum size",
             Self::FloatType => "Input should be a valid number",
-            Self::FloatParsing => "Input should be a valid number, unable to parse string as an number",
+            Self::FloatParsing => "Input should be a valid number, unable to parse string as a number",
             Self::BytesType => "Input should be a valid bytes",
             Self::BytesTooShort {..} => "Data should have at least {min_length} bytes",
             Self::BytesTooLong {..} => "Data should have at most {max_length} bytes",
@@ -540,7 +543,6 @@ impl ErrorType {
             Self::UnexpectedPositionalArgument => "Unexpected positional argument",
             Self::MissingPositionalOnlyArgument => "Missing required positional only argument",
             Self::MultipleArgumentValues => "Got multiple values for argument",
-            Self::DataclassType {..} => "Input should be a dictionary or an instance of {dataclass_name}",
             Self::UrlType => "URL input should be a string or URL",
             Self::UrlParsing {..} => "Input should be a valid URL, {error}",
             Self::UrlSyntaxViolation {..} => "Input violated strict URL syntax rules, {error}",
@@ -555,7 +557,9 @@ impl ErrorType {
             Self::ListType | Self::TupleType | Self::IterableType | Self::SetType | Self::FrozenSetType => {
                 "Input should be a valid array"
             }
-            Self::DictAttributesType | Self::DictType | Self::DataclassType { .. } => "Input should be an object",
+            Self::ModelType { .. } | Self::ModelAttributesType | Self::DictType | Self::DataclassType { .. } => {
+                "Input should be an object"
+            }
             Self::TimeDeltaType => "Input should be a valid duration",
             Self::TimeDeltaParsing { .. } => "Input should be a valid duration, {error}",
             Self::ArgumentsType => "Arguments must be an array or an object",
@@ -596,7 +600,9 @@ impl ErrorType {
             Self::NoSuchAttribute { attribute } => render!(tmpl, attribute),
             Self::JsonInvalid { error } => render!(tmpl, error),
             Self::GetAttributeError { error } => render!(tmpl, error),
-            Self::ModelClassType { class_name } => render!(tmpl, class_name),
+            Self::ModelType { class_name } => render!(tmpl, class_name),
+            Self::DataclassType { class_name } => render!(tmpl, class_name),
+            Self::DataclassExactType { class_name } => render!(tmpl, class_name),
             Self::GreaterThan { gt } => to_string_render!(tmpl, gt),
             Self::GreaterThanEqual { ge } => to_string_render!(tmpl, ge),
             Self::LessThan { lt } => to_string_render!(tmpl, lt),
@@ -607,7 +613,7 @@ impl ErrorType {
                 min_length,
                 actual_length,
             } => {
-                let expected_plural = plural_s(min_length);
+                let expected_plural = plural_s(*min_length);
                 to_string_render!(tmpl, field_type, min_length, actual_length, expected_plural)
             }
             Self::TooLong {
@@ -615,7 +621,7 @@ impl ErrorType {
                 max_length,
                 actual_length,
             } => {
-                let expected_plural = plural_s(max_length);
+                let expected_plural = plural_s(*max_length);
                 to_string_render!(tmpl, field_type, max_length, actual_length, expected_plural)
             }
             Self::IterationError { error } => render!(tmpl, error),
@@ -646,7 +652,6 @@ impl ErrorType {
                 expected_tags,
             } => render!(tmpl, discriminator, tag, expected_tags),
             Self::UnionTagNotFound { discriminator } => render!(tmpl, discriminator),
-            Self::DataclassType { dataclass_name } => render!(tmpl, dataclass_name),
             Self::UrlParsing { error } => render!(tmpl, error),
             Self::UrlSyntaxViolation { error } => render!(tmpl, error),
             Self::UrlTooLong { max_length } => to_string_render!(tmpl, max_length),
@@ -660,7 +665,9 @@ impl ErrorType {
             Self::NoSuchAttribute { attribute } => py_dict!(py, attribute),
             Self::JsonInvalid { error } => py_dict!(py, error),
             Self::GetAttributeError { error } => py_dict!(py, error),
-            Self::ModelClassType { class_name } => py_dict!(py, class_name),
+            Self::ModelType { class_name } => py_dict!(py, class_name),
+            Self::DataclassType { class_name } => py_dict!(py, class_name),
+            Self::DataclassExactType { class_name } => py_dict!(py, class_name),
             Self::GreaterThan { gt } => py_dict!(py, gt),
             Self::GreaterThanEqual { ge } => py_dict!(py, ge),
             Self::LessThan { lt } => py_dict!(py, lt),
@@ -704,7 +711,6 @@ impl ErrorType {
                 expected_tags,
             } => py_dict!(py, discriminator, tag, expected_tags),
             Self::UnionTagNotFound { discriminator } => py_dict!(py, discriminator),
-            Self::DataclassType { dataclass_name } => py_dict!(py, dataclass_name),
             Self::UrlParsing { error } => py_dict!(py, error),
             Self::UrlSyntaxViolation { error } => py_dict!(py, error),
             Self::UrlTooLong { max_length } => py_dict!(py, max_length),
@@ -728,18 +734,6 @@ impl Default for Number {
     }
 }
 
-impl From<i64> for Number {
-    fn from(i: i64) -> Self {
-        Self::Int(i)
-    }
-}
-
-impl From<BigInt> for Number {
-    fn from(i: BigInt) -> Self {
-        Self::BigInt(i)
-    }
-}
-
 impl From<f64> for Number {
     fn from(f: f64) -> Self {
         Self::Float(f)
@@ -751,6 +745,14 @@ impl From<String> for Number {
         Self::String(s)
     }
 }
+impl From<Int> for Number {
+    fn from(i: Int) -> Self {
+        match i {
+            Int::I64(i) => Number::Int(i),
+            Int::Big(b) => Number::BigInt(b),
+        }
+    }
+}
 
 impl FromPyObject<'_> for Number {
     fn extract(obj: &PyAny) -> PyResult<Self> {
