@@ -30,8 +30,8 @@ use super::ValError;
 #[cfg_attr(debug_assertions, derive(Debug))]
 pub struct ValidationError {
     line_errors: Vec<PyLineError>,
-    error_mode: ErrorMode,
     title: PyObject,
+    error_mode: ErrorMode,
     hide_input: bool,
 }
 
@@ -70,6 +70,7 @@ impl ValidationError {
             }
             ValError::InternalErr(err) => err,
             ValError::Omit => Self::omit_error(),
+            ValError::UseDefault => Self::use_default_error(),
         }
     }
 
@@ -89,6 +90,10 @@ impl ValidationError {
     pub fn omit_error() -> PyErr {
         py_schema_error_type!("Uncaught Omit error, please check your usage of `default` validators.")
     }
+
+    pub fn use_default_error() -> PyErr {
+        py_schema_error_type!("Uncaught UseDefault error, please check your usage of `default` validators.")
+    }
 }
 
 static URL_ENV_VAR: GILOnceCell<bool> = GILOnceCell::new();
@@ -128,12 +133,12 @@ impl<'a> IntoPy<ValError<'a>> for ValidationError {
 #[pymethods]
 impl ValidationError {
     #[staticmethod]
-    #[pyo3(signature = (title, line_errors, error_mode=None, hide_input=false))]
+    #[pyo3(signature = (title, line_errors, error_mode="python", hide_input=false))]
     fn from_exception_data(
         py: Python,
         title: PyObject,
         line_errors: &PyList,
-        error_mode: Option<&str>,
+        error_mode: &str,
         hide_input: bool,
     ) -> PyResult<Py<Self>> {
         Py::new(
@@ -186,7 +191,7 @@ impl ValidationError {
         include_url: bool,
         include_context: bool,
     ) -> PyResult<&'py PyString> {
-        let state = SerializationState::new(None, None);
+        let state = SerializationState::new("iso8601", "utf8")?;
         let extra = state.extra(py, &SerMode::Json, true, false, false, true, None);
         let serializer = ValidationErrorSerializer {
             py,
