@@ -10,8 +10,8 @@ use super::datetime::{
 use super::parse_json::JsonArray;
 use super::shared::{float_as_int, int_as_bool, map_json_err, str_as_bool, str_as_int};
 use super::{
-    EitherBytes, EitherInt, EitherString, EitherTimedelta, GenericArguments, GenericIterable, GenericIterator,
-    GenericMapping, Input, JsonArgs, JsonInput,
+    EitherBytes, EitherFloat, EitherInt, EitherString, EitherTimedelta, GenericArguments, GenericIterable,
+    GenericIterator, GenericMapping, Input, JsonArgs, JsonInput,
 };
 
 impl<'a> Input<'a> for JsonInput {
@@ -54,12 +54,12 @@ impl<'a> Input<'a> for JsonInput {
         }
     }
 
-    fn validate_dataclass_args(&'a self, dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_dataclass_args(&'a self, class_name: &str) -> ValResult<'a, GenericArguments<'a>> {
         match self {
             JsonInput::Object(object) => Ok(JsonArgs::new(None, Some(object)).into()),
             _ => {
-                let dataclass_name = dataclass_name.to_string();
-                Err(ValError::new(ErrorType::DataclassType { dataclass_name }, self))
+                let class_name = class_name.to_string();
+                Err(ValError::new(ErrorType::DataclassType { class_name }, self))
             }
         }
     }
@@ -135,31 +135,31 @@ impl<'a> Input<'a> for JsonInput {
         }
     }
 
-    fn ultra_strict_float(&self) -> ValResult<f64> {
+    fn ultra_strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
         match self {
-            JsonInput::Float(f) => Ok(*f),
+            JsonInput::Float(f) => Ok(EitherFloat::F64(*f)),
             _ => Err(ValError::new(ErrorType::FloatType, self)),
         }
     }
-    fn strict_float(&self) -> ValResult<f64> {
+    fn strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
         match self {
-            JsonInput::Float(f) => Ok(*f),
-            JsonInput::Int(i) => Ok(*i as f64),
-            JsonInput::Uint(u) => Ok(*u as f64),
+            JsonInput::Float(f) => Ok(EitherFloat::F64(*f)),
+            JsonInput::Int(i) => Ok(EitherFloat::F64(*i as f64)),
+            JsonInput::Uint(u) => Ok(EitherFloat::F64(*u as f64)),
             _ => Err(ValError::new(ErrorType::FloatType, self)),
         }
     }
-    fn lax_float(&self) -> ValResult<f64> {
+    fn lax_float(&'a self) -> ValResult<EitherFloat<'a>> {
         match self {
             JsonInput::Bool(b) => match *b {
-                true => Ok(1.0),
-                false => Ok(0.0),
+                true => Ok(EitherFloat::F64(1.0)),
+                false => Ok(EitherFloat::F64(0.0)),
             },
-            JsonInput::Float(f) => Ok(*f),
-            JsonInput::Int(i) => Ok(*i as f64),
-            JsonInput::Uint(u) => Ok(*u as f64),
+            JsonInput::Float(f) => Ok(EitherFloat::F64(*f)),
+            JsonInput::Int(i) => Ok(EitherFloat::F64(*i as f64)),
+            JsonInput::Uint(u) => Ok(EitherFloat::F64(*u as f64)),
             JsonInput::String(str) => match str.parse::<f64>() {
-                Ok(i) => Ok(i),
+                Ok(i) => Ok(EitherFloat::F64(i)),
                 Err(_) => Err(ValError::new(ErrorType::FloatParsing, self)),
             },
             _ => Err(ValError::new(ErrorType::FloatType, self)),
@@ -330,9 +330,9 @@ impl<'a> Input<'a> for String {
     }
 
     #[cfg_attr(has_no_coverage, no_coverage)]
-    fn validate_dataclass_args(&'a self, dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
-        let dataclass_name = dataclass_name.to_string();
-        Err(ValError::new(ErrorType::DataclassType { dataclass_name }, self))
+    fn validate_dataclass_args(&'a self, class_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+        let class_name = class_name.to_string();
+        Err(ValError::new(ErrorType::DataclassType { class_name }, self))
     }
 
     fn parse_json(&'a self) -> ValResult<'a, JsonInput> {
@@ -372,16 +372,16 @@ impl<'a> Input<'a> for String {
     }
 
     #[cfg_attr(has_no_coverage, no_coverage)]
-    fn ultra_strict_float(&self) -> ValResult<f64> {
+    fn ultra_strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
         self.strict_float()
     }
     #[cfg_attr(has_no_coverage, no_coverage)]
-    fn strict_float(&self) -> ValResult<f64> {
+    fn strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
         Err(ValError::new(ErrorType::FloatType, self))
     }
-    fn lax_float(&self) -> ValResult<f64> {
+    fn lax_float(&'a self) -> ValResult<EitherFloat<'a>> {
         match self.parse() {
-            Ok(i) => Ok(i),
+            Ok(f) => Ok(EitherFloat::F64(f)),
             Err(_) => Err(ValError::new(ErrorType::FloatParsing, self)),
         }
     }
