@@ -3,7 +3,7 @@ use std::str::from_utf8;
 
 use pyo3::prelude::*;
 use pyo3::types::{
-    PyBool, PyByteArray, PyBytes, PyDate, PyDateTime, PyDelta, PyDict, PyFrozenSet, PyInt, PyIterator, PyList,
+    PyBool, PyByteArray, PyBytes, PyDate, PyDateTime, PyDelta, PyDict, PyFloat, PyFrozenSet, PyInt, PyIterator, PyList,
     PyMapping, PySequence, PySet, PyString, PyTime, PyTuple, PyType,
 };
 #[cfg(not(PyPy))]
@@ -21,8 +21,8 @@ use super::datetime::{
 };
 use super::shared::{float_as_int, int_as_bool, map_json_err, str_as_bool, str_as_int};
 use super::{
-    py_string_str, EitherBytes, EitherInt, EitherString, EitherTimedelta, GenericArguments, GenericIterable,
-    GenericIterator, GenericMapping, Input, JsonInput, PyArgs,
+    py_string_str, EitherBytes, EitherFloat, EitherInt, EitherString, EitherTimedelta, GenericArguments,
+    GenericIterable, GenericIterator, GenericMapping, Input, JsonInput, PyArgs,
 };
 
 #[cfg(not(PyPy))]
@@ -159,7 +159,7 @@ impl<'a> Input<'a> for PyAny {
         }
     }
 
-    fn validate_dataclass_args(&'a self, dataclass_name: &str) -> ValResult<'a, GenericArguments<'a>> {
+    fn validate_dataclass_args(&'a self, class_name: &str) -> ValResult<'a, GenericArguments<'a>> {
         if let Ok(dict) = self.downcast::<PyDict>() {
             Ok(PyArgs::new(None, Some(dict)).into())
         } else if let Ok(args_kwargs) = self.extract::<ArgsKwargs>() {
@@ -167,8 +167,8 @@ impl<'a> Input<'a> for PyAny {
             let kwargs = args_kwargs.kwargs.map(|d| d.into_ref(self.py()));
             Ok(PyArgs::new(Some(args), kwargs).into())
         } else {
-            let dataclass_name = dataclass_name.to_string();
-            Err(ValError::new(ErrorType::DataclassType { dataclass_name }, self))
+            let class_name = class_name.to_string();
+            Err(ValError::new(ErrorType::DataclassType { class_name }, self))
         }
     }
 
@@ -186,15 +186,21 @@ impl<'a> Input<'a> for PyAny {
     }
 
     fn strict_str(&'a self) -> ValResult<EitherString<'a>> {
-        if let Ok(py_str) = <PyString as PyTryFrom>::try_from_exact(self) {
+        if let Ok(py_str) = <PyString as PyTryFrom>::try_from(self) {
             Ok(py_str.into())
-        } else if PyString::is_type_of(self) {
-            Err(ValError::new(ErrorType::StringSubType, self))
         } else {
             Err(ValError::new(ErrorType::StringType, self))
         }
     }
 
+    fn exact_str(&'a self) -> ValResult<EitherString<'a>> {
+        if let Ok(py_str) = <PyString as PyTryFrom>::try_from_exact(self) {
+            Ok(EitherString::Py(py_str))
+        } else {
+            Err(ValError::new(ErrorType::IntType, self))
+        }
+    }
+
     fn exact_int(&'a self) -> ValResult<EitherInt<'a>> {
         if PyInt::is_exact_type_of(self) {
             Ok(EitherInt::Py(self))
@@ -302,35 +308,40 @@ impl<'a> Input<'a> for PyAny {
         }
     }
 
-    fn ultra_strict_float(&self) -> ValResult<f64> {
+    fn ultra_strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
         if self.is_instance_of::<PyInt>() {
             Err(ValError::new(ErrorType::FloatType, self))
-        } else if let Ok(float) = self.extract::<f64>() {
-            Ok(float)
+        } else if self.is_instance_of::<PyFloat>() {
+            Ok(EitherFloat::Py(self))
         } else {
             Err(ValError::new(ErrorType::FloatType, self))
         }
     }
-    fn strict_float(&self) -> ValResult<f64> {
-        if let Ok(float) = self.extract::<f64>() {
+    fn strict_float(&'a self) -> ValResult<EitherFloat<'a>> {
+        if PyFloat::is_exact_type_of(self) {
+            Ok(EitherFloat::Py(self))
+        } else if let Ok(float) = self.extract::<f64>() {
             // bools are cast to floats as either 0.0 or 1.0, so check for bool type in this specific case
             if (float == 0.0 || float == 1.0) && PyBool::is_exact_type_of(self) {
                 Err(ValError::new(ErrorType::FloatType, self))
             } else {
-                Ok(float)
+                Ok(EitherFloat::Py(self))
             }
         } else {
             Err(ValError::new(ErrorType::FloatType, self))
         }
     }
-    fn lax_float(&self) -> ValResult<f64> {
-        if let Ok(float) = self.extract::<f64>() {
-            Ok(float)
+
+    fn lax_float(&'a self) -> ValResult<EitherFloat<'a>> {
+        if PyFloat::is_exact_type_of(self) {
+            Ok(EitherFloat::Py(self))
         } else if let Some(cow_str) = maybe_as_string(self, ErrorType::FloatParsing)? {
             match cow_str.as_ref().parse::<f64>() {
-                Ok(i) => Ok(i),
+                Ok(i) => Ok(EitherFloat::F64(i)),
                 Err(_) => Err(ValError::new(ErrorType::FloatParsing, self)),
             }
+        } else if let Ok(float) = self.extract::<f64>() {
+            Ok(EitherFloat::F64(float))
         } else {
             Err(ValError::new(ErrorType::FloatType, self))
         }
@@ -371,11 +382,11 @@ impl<'a> Input<'a> for PyAny {
                 if from_attributes_applicable(obj) {
                     Ok(GenericMapping::PyGetAttr(obj, Some(kwargs)))
                 } else {
-                    Err(ValError::new(ErrorType::DictAttributesType, self))
+                    Err(ValError::new(ErrorType::ModelAttributesType, self))
                 }
             } else {
                 // note the error here gives a hint about from_attributes
-                Err(ValError::new(ErrorType::DictAttributesType, self))
+                Err(ValError::new(ErrorType::ModelAttributesType, self))
             }
         } else {
             // otherwise we just call back to validate_dict if from_mapping is allowed, note that errors in this
