@@ -1,11 +1,10 @@
 #![cfg_attr(has_no_coverage, feature(no_coverage))]
-#![allow(clippy::borrow_deref_ref)]
 
 extern crate core;
 
 use pyo3::prelude::*;
 
-#[cfg(feature = "mimalloc-allocator")]
+#[cfg(feature = "mimalloc")]
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
@@ -24,9 +23,11 @@ mod validators;
 
 // required for benchmarks
 pub use self::url::{PyMultiHostUrl, PyUrl};
-pub use argument_markers::{ArgsKwargs, UndefinedType};
+pub use argument_markers::{ArgsKwargs, PydanticUndefinedType};
 pub use build_tools::SchemaError;
-pub use errors::{list_all_errors, PydanticCustomError, PydanticKnownError, PydanticOmit, ValidationError};
+pub use errors::{
+    list_all_errors, PydanticCustomError, PydanticKnownError, PydanticOmit, PydanticUseDefault, ValidationError,
+};
 pub use serializers::{
     to_json, to_jsonable_python, PydanticSerializationError, PydanticSerializationUnexpectedValue, SchemaSerializer,
 };
@@ -46,7 +47,8 @@ pub fn get_version() -> String {
 fn _pydantic_core(py: Python, m: &PyModule) -> PyResult<()> {
     m.add("__version__", get_version())?;
     m.add("build_profile", env!("PROFILE"))?;
-    m.add("PydanticUndefined", UndefinedType::new(py))?;
+    m.add("PydanticUndefined", PydanticUndefinedType::new(py))?;
+    m.add_class::<PydanticUndefinedType>()?;
     m.add_class::<PySome>()?;
     m.add_class::<SchemaValidator>()?;
     m.add_class::<ValidationError>()?;
@@ -54,6 +56,7 @@ fn _pydantic_core(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<PydanticCustomError>()?;
     m.add_class::<PydanticKnownError>()?;
     m.add_class::<PydanticOmit>()?;
+    m.add_class::<PydanticUseDefault>()?;
     m.add_class::<PydanticSerializationError>()?;
     m.add_class::<PydanticSerializationUnexpectedValue>()?;
     m.add_class::<PyUrl>()?;
@@ -63,5 +66,9 @@ fn _pydantic_core(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(to_json, m)?)?;
     m.add_function(wrap_pyfunction!(to_jsonable_python, m)?)?;
     m.add_function(wrap_pyfunction!(list_all_errors, m)?)?;
+
+    #[cfg(not(feature = "mimalloc"))]
+    m.setattr("__pydantic_core_default_allocator__", true)?; // uses setattr so this is not in __all__
+
     Ok(())
 }
