@@ -1,5 +1,5 @@
 use std::borrow::Cow;
-use std::str::{from_utf8, Utf8Error};
+use std::str::{from_utf8, FromStr, Utf8Error};
 
 use pyo3::prelude::*;
 use pyo3::types::{PyDelta, PyDict};
@@ -29,42 +29,42 @@ impl SerializationConfig {
         })
     }
 
-    pub fn from_args(timedelta_mode: Option<&str>, bytes_mode: Option<&str>) -> PyResult<Self> {
-        let timedelta_mode = TimedeltaMode::from_str(timedelta_mode)?;
-        let bytes_mode = BytesMode::from_str(bytes_mode)?;
+    pub fn from_args(timedelta_mode: &str, bytes_mode: &str) -> PyResult<Self> {
         Ok(Self {
-            timedelta_mode,
-            bytes_mode,
+            timedelta_mode: TimedeltaMode::from_str(timedelta_mode)?,
+            bytes_mode: BytesMode::from_str(bytes_mode)?,
         })
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Default, Debug, Clone)]
 pub(crate) enum TimedeltaMode {
+    #[default]
     Iso8601,
     Float,
 }
 
-impl TimedeltaMode {
-    pub fn from_config(config: Option<&PyDict>) -> PyResult<Self> {
-        let raw_mode: Option<&str> = match config {
-            Some(c) => c.get_as::<&str>(intern!(c.py(), "ser_json_timedelta"))?,
-            None => None,
-        };
-        Self::from_str(raw_mode)
-    }
+impl FromStr for TimedeltaMode {
+    type Err = PyErr;
 
-    pub fn from_str(s: Option<&str>) -> PyResult<Self> {
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
         match s {
-            Some("iso8601") => Ok(Self::Iso8601),
-            Some("float") => Ok(Self::Float),
-            Some(s) => py_schema_err!(
+            "iso8601" => Ok(Self::Iso8601),
+            "float" => Ok(Self::Float),
+            s => py_schema_err!(
                 "Invalid timedelta serialization mode: `{}`, expected `iso8601` or `float`",
                 s
             ),
-            None => Ok(Self::Iso8601),
         }
     }
+}
+
+impl TimedeltaMode {
+    pub fn from_config(config: Option<&PyDict>) -> PyResult<Self> {
+        let Some(config_dict) = config else { return Ok(Self::default()) };
+        let raw_mode = config_dict.get_as::<&str>(intern!(config_dict.py(), "ser_json_timedelta"))?;
+        raw_mode.map_or_else(|| Ok(Self::default()), Self::from_str)
+    }
 
     fn total_seconds(py_timedelta: &PyDelta) -> PyResult<&PyAny> {
         py_timedelta.call_method0(intern!(py_timedelta.py(), "total_seconds"))
@@ -116,29 +116,30 @@ impl TimedeltaMode {
     }
 }
 
-#[derive(Debug, Clone)]
+#[derive(Default, Debug, Clone)]
 pub(crate) struct BytesMode {
     base64_config: Option<base64::Config>,
 }
 
-impl BytesMode {
-    pub fn from_config(config: Option<&PyDict>) -> PyResult<Self> {
-        let raw_mode: Option<&str> = match config {
-            Some(c) => c.get_as::<&str>(intern!(c.py(), "ser_json_bytes"))?,
-            None => None,
-        };
-        Self::from_str(raw_mode)
-    }
+impl FromStr for BytesMode {
+    type Err = PyErr;
 
-    pub fn from_str(s: Option<&str>) -> PyResult<Self> {
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
         let base64_config = match s {
-            Some("utf8") => None,
-            Some("base64") => Some(base64::Config::new(base64::CharacterSet::UrlSafe, true)),
-            Some(s) => return py_schema_err!("Invalid bytes serialization mode: `{}`, expected `utf8` or `base64`", s),
-            None => None,
+            "utf8" => None,
+            "base64" => Some(base64::Config::new(base64::CharacterSet::UrlSafe, true)),
+            s => return py_schema_err!("Invalid bytes serialization mode: `{}`, expected `utf8` or `base64`", s),
         };
         Ok(Self { base64_config })
     }
+}
+
+impl BytesMode {
+    pub fn from_config(config: Option<&PyDict>) -> PyResult<Self> {
+        let Some(config_dict) = config else { return Ok(Self::default()) };
+        let raw_mode = config_dict.get_as::<&str>(intern!(config_dict.py(), "ser_json_bytes"))?;
+        raw_mode.map_or_else(|| Ok(Self::default()), Self::from_str)
+    }
 
     pub fn bytes_to_string<'py>(&self, py: Python, bytes: &'py [u8]) -> PyResult<Cow<'py, str>> {
         if let Some(config) = self.base64_config {
