@@ -7,8 +7,8 @@ use pyo3::types::PyDict;
 
 use serde::ser::Error;
 
-use crate::build_tools::SchemaDict;
 use crate::definitions::DefinitionsBuilder;
+use crate::tools::SchemaDict;
 
 use super::any::AnySerializer;
 use super::{
