@@ -72,7 +72,7 @@ impl PyUrl {
     pub fn unicode_host(&self) -> Option<String> {
         match self.lib_url.host() {
             Some(url::Host::Domain(domain)) if is_punnycode_domain(&self.lib_url, domain) => decode_punycode(domain),
-            _ => self.lib_url.host_str().map(|h| h.to_string()),
+            _ => self.lib_url.host_str().map(ToString::to_string),
         }
     }
 
@@ -142,9 +142,14 @@ impl PyUrl {
         true // an empty string is not a valid URL
     }
 
+    #[pyo3(signature = (_memo, /))]
     pub fn __deepcopy__(&self, py: Python, _memo: &PyDict) -> Py<PyAny> {
         self.clone().into_py(py)
     }
+
+    fn __getnewargs__(&self) -> (&str,) {
+        (self.__str__(),)
+    }
 }
 
 #[pyclass(name = "MultiHostUrl", module = "pydantic_core._pydantic_core", subclass)]
@@ -277,7 +282,7 @@ impl PyMultiHostUrl {
     }
 
     pub fn __repr__(&self) -> String {
-        format!("Url('{}')", self.__str__())
+        format!("MultiHostUrl('{}')", self.__str__())
     }
 
     fn __richcmp__(&self, other: &Self, op: CompareOp) -> PyResult<bool> {
@@ -305,6 +310,10 @@ impl PyMultiHostUrl {
     pub fn __deepcopy__(&self, py: Python, _memo: &PyDict) -> Py<PyAny> {
         self.clone().into_py(py)
     }
+
+    fn __getnewargs__(&self) -> (String,) {
+        (self.__str__(),)
+    }
 }
 
 fn host_to_dict<'a>(py: Python<'a>, lib_url: &Url) -> PyResult<&'a PyDict> {
@@ -331,7 +340,7 @@ fn unicode_url(lib_url: &Url) -> String {
             if let Some(decoded) = decode_punycode(domain) {
                 // replace the range containing the punycode domain with the decoded domain
                 let start = lib_url.scheme().len() + 3;
-                s.replace_range(start..start + domain.len(), &decoded)
+                s.replace_range(start..start + domain.len(), &decoded);
             }
             s
         }
