@@ -3,10 +3,10 @@ use std::fmt;
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
 
-use crate::build_tools::SchemaDict;
 use crate::errors::{ErrorMode, ErrorType, LocItem, ValError, ValResult};
 use crate::input::{GenericIterator, Input};
 use crate::recursion_guard::RecursionGuard;
+use crate::tools::SchemaDict;
 use crate::ValidationError;
 
 use super::list::get_items_schema;
@@ -18,6 +18,7 @@ pub struct GeneratorValidator {
     min_length: Option<usize>,
     max_length: Option<usize>,
     name: String,
+    hide_input_in_errors: bool,
 }
 
 impl BuildValidator for GeneratorValidator {
@@ -33,11 +34,15 @@ impl BuildValidator for GeneratorValidator {
             Some(ref v) => format!("{}[{}]", Self::EXPECTED_TYPE, v.get_name()),
             None => format!("{}[any]", Self::EXPECTED_TYPE),
         };
+        let hide_input_in_errors: bool = config
+            .get_as(pyo3::intern!(schema.py(), "hide_input_in_errors"))?
+            .unwrap_or(false);
         Ok(Self {
             item_validator,
             name,
             min_length: schema.get_as(pyo3::intern!(schema.py(), "min_length"))?,
             max_length: schema.get_as(pyo3::intern!(schema.py(), "max_length"))?,
+            hide_input_in_errors,
         }
         .into())
     }
@@ -53,16 +58,24 @@ impl Validator for GeneratorValidator {
         recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
         let iterator = input.validate_iter()?;
-        let validator = self
-            .item_validator
-            .as_ref()
-            .map(|v| InternalValidator::new(py, "ValidatorIterator", v, definitions, extra, recursion_guard));
+        let validator = self.item_validator.as_ref().map(|v| {
+            InternalValidator::new(
+                py,
+                "ValidatorIterator",
+                v,
+                definitions,
+                extra,
+                recursion_guard,
+                self.hide_input_in_errors,
+            )
+        });
 
         let v_iterator = ValidatorIterator {
             iterator,
             validator,
             min_length: self.min_length,
             max_length: self.max_length,
+            hide_input_in_errors: self.hide_input_in_errors,
         };
         Ok(v_iterator.into_py(py))
     }
@@ -98,6 +111,7 @@ struct ValidatorIterator {
     validator: Option<InternalValidator>,
     min_length: Option<usize>,
     max_length: Option<usize>,
+    hide_input_in_errors: bool,
 }
 
 #[pymethods]
@@ -109,6 +123,7 @@ impl ValidatorIterator {
     fn __next__(mut slf: PyRefMut<'_, Self>, py: Python) -> PyResult<Option<PyObject>> {
         let min_length = slf.min_length;
         let max_length = slf.max_length;
+        let hide_input_in_errors = slf.hide_input_in_errors;
         let Self {
             validator, iterator, ..
         } = &mut *slf;
@@ -133,6 +148,7 @@ impl ValidatorIterator {
                                         ErrorMode::Python,
                                         val_error,
                                         None,
+                                        hide_input_in_errors,
                                     ));
                                 }
                             }
@@ -157,6 +173,7 @@ impl ValidatorIterator {
                                     ErrorMode::Python,
                                     val_error,
                                     None,
+                                    hide_input_in_errors,
                                 ));
                             }
                         }
@@ -199,10 +216,12 @@ pub struct InternalValidator {
     // TODO, do we need data?
     data: Option<Py<PyDict>>,
     strict: Option<bool>,
+    from_attributes: Option<bool>,
     context: Option<PyObject>,
     self_instance: Option<PyObject>,
     recursion_guard: RecursionGuard,
     validation_mode: InputType,
+    hide_input_in_errors: bool,
 }
 
 impl fmt::Debug for InternalValidator {
@@ -219,6 +238,7 @@ impl InternalValidator {
         definitions: &[CombinedValidator],
         extra: &Extra,
         recursion_guard: &RecursionGuard,
+        hide_input_in_errors: bool,
     ) -> Self {
         Self {
             name: name.to_string(),
@@ -226,10 +246,12 @@ impl InternalValidator {
             definitions: definitions.to_vec(),
             data: extra.data.map(|d| d.into_py(py)),
             strict: extra.strict,
+            from_attributes: extra.from_attributes,
             context: extra.context.map(|d| d.into_py(py)),
             self_instance: extra.self_instance.map(|d| d.into_py(py)),
             recursion_guard: recursion_guard.clone(),
             validation_mode: extra.mode,
+            hide_input_in_errors,
         }
     }
 
@@ -246,6 +268,7 @@ impl InternalValidator {
             data: self.data.as_ref().map(|data| data.as_ref(py)),
             strict: self.strict,
             ultra_strict: false,
+            from_attributes: self.from_attributes,
             context: self.context.as_ref().map(|data| data.as_ref(py)),
             field_name: None,
             self_instance: self.self_instance.as_ref().map(|data| data.as_ref(py)),
@@ -261,7 +284,14 @@ impl InternalValidator {
                 &mut self.recursion_guard,
             )
             .map_err(|e| {
-                ValidationError::from_val_error(py, self.name.to_object(py), ErrorMode::Python, e, outer_location)
+                ValidationError::from_val_error(
+                    py,
+                    self.name.to_object(py),
+                    ErrorMode::Python,
+                    e,
+                    outer_location,
+                    self.hide_input_in_errors,
+                )
             })
     }
 
@@ -279,6 +309,7 @@ impl InternalValidator {
             data: self.data.as_ref().map(|data| data.as_ref(py)),
             strict: self.strict,
             ultra_strict: false,
+            from_attributes: self.from_attributes,
             context: self.context.as_ref().map(|data| data.as_ref(py)),
             field_name: None,
             self_instance: self.self_instance.as_ref().map(|data| data.as_ref(py)),
@@ -286,7 +317,14 @@ impl InternalValidator {
         self.validator
             .validate(py, input, &extra, &self.definitions, &mut self.recursion_guard)
             .map_err(|e| {
-                ValidationError::from_val_error(py, self.name.to_object(py), ErrorMode::Python, e, outer_location)
+                ValidationError::from_val_error(
+                    py,
+                    self.name.to_object(py),
+                    ErrorMode::Python,
+                    e,
+                    outer_location,
+                    self.hide_input_in_errors,
+                )
             })
     }
 }
