@@ -82,7 +82,8 @@ impl PySome {
     }
 
     #[classmethod]
-    pub fn __class_getitem__(cls: &PyType, _args: &PyAny) -> Py<PyType> {
+    #[pyo3(signature = (_item, /))]
+    pub fn __class_getitem__(cls: &PyType, _item: &PyAny) -> Py<PyType> {
         cls.into_py(cls.py())
     }
 
@@ -115,7 +116,7 @@ impl SchemaValidator {
         let mut validator = build_validator(schema, config, &mut definitions_builder)?;
         validator.complete(&definitions_builder)?;
         let mut definitions = definitions_builder.clone().finish()?;
-        for val in definitions.iter_mut() {
+        for val in &mut definitions {
             val.complete(&definitions_builder)?;
         }
         let config_title = match config {
@@ -138,7 +139,7 @@ impl SchemaValidator {
 
     pub fn __reduce__(&self, py: Python) -> PyResult<PyObject> {
         let args = (self.schema.as_ref(py),);
-        let cls = Py::new(py, self.to_owned())?.getattr(py, "__class__")?;
+        let cls = Py::new(py, self.clone())?.getattr(py, "__class__")?;
         Ok((cls, args).into_py(py))
     }
 
@@ -186,6 +187,7 @@ impl SchemaValidator {
             Ok(_) => Ok(true),
             Err(ValError::InternalErr(err)) => Err(err),
             Err(ValError::Omit) => Err(ValidationError::omit_error()),
+            Err(ValError::UseDefault) => Err(ValidationError::use_default_error()),
             Err(ValError::LineErrors(_)) => Ok(false),
         }
     }
@@ -274,7 +276,7 @@ impl SchemaValidator {
     fn __traverse__(&self, visit: PyVisit<'_>) -> Result<(), PyTraverseError> {
         self.validator.py_gc_traverse(&visit)?;
         visit.call(&self.schema)?;
-        for slot in self.definitions.iter() {
+        for slot in &self.definitions {
             slot.py_gc_traverse(&visit)?;
         }
         Ok(())
@@ -282,7 +284,7 @@ impl SchemaValidator {
 
     fn __clear__(&mut self) {
         self.validator.py_gc_clear();
-        for slot in self.definitions.iter_mut() {
+        for slot in &mut self.definitions {
             slot.py_gc_clear();
         }
     }
@@ -368,7 +370,7 @@ impl<'py> SelfValidator<'py> {
         };
         validator.complete(&definitions_builder)?;
         let mut definitions = definitions_builder.clone().finish()?;
-        for val in definitions.iter_mut() {
+        for val in &mut definitions {
             val.complete(&definitions_builder)?;
         }
         Ok(SchemaValidator {
