@@ -10,7 +10,7 @@ use crate::errors::{LocItem, ValError, ValResult};
 use crate::input::Input;
 use crate::recursion_guard::RecursionGuard;
 use crate::tools::SchemaDict;
-use crate::UndefinedType;
+use crate::PydanticUndefinedType;
 
 static COPY_DEEPCOPY: GILOnceCell<PyObject> = GILOnceCell::new();
 
@@ -121,19 +121,24 @@ impl Validator for WithDefaultValidator {
         definitions: &'data Definitions<CombinedValidator>,
         recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
-        if input.to_object(py).is(&UndefinedType::py_undefined()) {
+        if input.to_object(py).is(&PydanticUndefinedType::py_undefined()) {
             Ok(self
                 .default_value(py, None::<usize>, extra, definitions, recursion_guard)?
                 .unwrap())
         } else {
             match self.validator.validate(py, input, extra, definitions, recursion_guard) {
                 Ok(v) => Ok(v),
-                Err(e) => match self.on_error {
-                    OnError::Raise => Err(e),
-                    OnError::Default => Ok(self
+                Err(e) => match e {
+                    ValError::UseDefault => Ok(self
                         .default_value(py, None::<usize>, extra, definitions, recursion_guard)?
-                        .unwrap()),
-                    OnError::Omit => Err(ValError::Omit),
+                        .ok_or(e)?),
+                    e => match self.on_error {
+                        OnError::Raise => Err(e),
+                        OnError::Default => Ok(self
+                            .default_value(py, None::<usize>, extra, definitions, recursion_guard)?
+                            .ok_or(e)?),
+                        OnError::Omit => Err(ValError::Omit),
+                    },
                 },
             }
         }
