@@ -23,7 +23,7 @@ class TestBenchmarkSimpleModel:
     @pytest.fixture(scope='class')
     def core_schema(self):
         class CoreModel:
-            __slots__ = '__dict__', '__pydantic_extra__', '__pydantic_fields_set__'
+            __slots__ = '__dict__', '__pydantic_fields_set__', '__pydantic_extra__', '__pydantic_private__'
 
         return {
             'type': 'model',
@@ -190,7 +190,9 @@ def test_date_format_function(benchmark):
 
     serializer = SchemaSerializer(
         core_schema.any_schema(
-            serialization=core_schema.plain_serializer_function_ser_schema(fmt, info_arg=True, json_return_type='str')
+            serialization=core_schema.plain_serializer_function_ser_schema(
+                fmt, info_arg=True, return_schema=core_schema.str_schema()
+            )
         )
     )
     d = date(2022, 11, 20)
@@ -206,7 +208,7 @@ def test_date_format_function_no_info(benchmark):
 
     serializer = SchemaSerializer(
         core_schema.any_schema(
-            serialization=core_schema.plain_serializer_function_ser_schema(fmt, json_return_type='str')
+            serialization=core_schema.plain_serializer_function_ser_schema(fmt, return_schema=core_schema.str_schema())
         )
     )
     d = date(2022, 11, 20)
@@ -335,7 +337,7 @@ def test_core_model_json_extra(benchmark, basic_model_serializer_extra):
 
 
 class FieldsSetModel:
-    __slots__ = '__dict__', '__pydantic_extra__', '__pydantic_fields_set__'
+    __slots__ = '__dict__', '__pydantic_fields_set__', '__pydantic_extra__', '__pydantic_private__'
 
     def __init__(self, **kwargs):
         for key, value in kwargs.items():
@@ -459,3 +461,12 @@ def test_to_string_direct(benchmark):
     assert s.to_json(123) == b'"123"'
 
     benchmark(s.to_json, 123)
+
+
+def test_filter(benchmark):
+    v = SchemaSerializer(core_schema.list_schema(core_schema.any_schema()))
+    assert v.to_python(['a', 'b', 'c', 'd', 'e'], include={-1, -2}) == ['d', 'e']
+
+    @benchmark
+    def t():
+        v.to_python(['a', 'b', 'c', 'd', 'e'], include={-1, -2})
