@@ -36,11 +36,17 @@ class MyDataclass:
 
 
 class MyModel:
-    __pydantic_serializer__ = 42
-
     def __init__(self, **kwargs):
+        fields = {}
         for key, value in kwargs.items():
             setattr(self, key, value)
+            fields[key] = core_schema.model_field(core_schema.any_schema())
+        self.__pydantic_serializer__ = SchemaSerializer(
+            core_schema.model_schema(MyModel, core_schema.model_fields_schema(fields))
+        )
+
+    def __repr__(self):
+        return f'MyModel({self.__dict__})'
 
 
 @pytest.mark.parametrize('value', [None, 1, 1.0, True, 'foo', [1, 2, 3], {'a': 1, 'b': 2}])
@@ -58,6 +64,7 @@ def test_any_json_round_trip(any_serializer, value):
         ({1, 2, 3}, {1, 2, 3}, IsList(1, 2, 3, check_order=False)),
         ({1, '2', b'3'}, {1, '2', b'3'}, IsList(1, '2', '3', check_order=False)),
     ],
+    ids=repr,
 )
 def test_any_python(any_serializer, input_value, expected_plain, expected_json_obj):
     assert any_serializer.to_python(input_value) == expected_plain
@@ -203,6 +210,7 @@ def test_include_list_tuple(any_serializer, seq_f):
     assert any_serializer.to_json(seq_f('a', 'b', 'c')) == b'["a","b","c"]'
 
     assert any_serializer.to_python(seq_f(0, 1, 2, 3), include={1, 2}) == seq_f(1, 2)
+    assert any_serializer.to_python(seq_f(0, 1, 2, 3), include={-1, -2}) == seq_f(2, 3)
     assert any_serializer.to_python(seq_f(0, 1, 2, 3), include={1, 2}, mode='json') == [1, 2]
     assert any_serializer.to_python(seq_f('a', 'b', 'c', 'd'), include={1, 2}) == seq_f('b', 'c')
     assert any_serializer.to_python(seq_f('a', 'b', 'c', 'd'), include={1, 2}, mode='json') == ['b', 'c']
@@ -242,13 +250,24 @@ def test_include_dict(any_serializer):
     assert any_serializer.to_json(MyDataclass(a=1, b='foo', frog=2), include={'a'}) == b'{"a":1}'
 
 
+def test_exclude_dict(any_serializer):
+    assert any_serializer.to_python({1: 2, '3': 4}) == {1: 2, '3': 4}
+    assert any_serializer.to_python({1: 2, 3: 4}, exclude={1}) == {3: 4}
+    assert any_serializer.to_python({1: 2, 3: 4}, exclude={-1}) == {1: 2, 3: 4}
+
+
 class FieldsSetModel:
     __pydantic_serializer__ = 42
-    __slots__ = '__dict__', '__pydantic_extra__', '__pydantic_fields_set__'
+    __slots__ = '__dict__', '__pydantic_fields_set__', '__pydantic_extra__', '__pydantic_private__'
 
     def __init__(self, **kwargs):
+        fields = {}
         for key, value in kwargs.items():
             setattr(self, key, value)
+            fields[key] = core_schema.model_field(core_schema.any_schema())
+        self.__pydantic_serializer__ = SchemaSerializer(
+            core_schema.model_schema(MyModel, core_schema.model_fields_schema(fields))
+        )
 
 
 def test_exclude_unset(any_serializer):
@@ -427,6 +446,7 @@ def test_any_dataclass():
         core_schema.dataclass_args_schema(
             'Foo', [core_schema.dataclass_field(name='a', schema=core_schema.str_schema())]
         ),
+        ['a'],
     )
     Foo.__pydantic_serializer__ = SchemaSerializer(schema)
 
@@ -444,20 +464,18 @@ def test_any_dataclass():
 
 
 def test_any_model():
+    @dataclasses.dataclass
     class Foo:
         a: str
         b: bytes
 
-        def __init__(self, a: str, b: bytes):
-            self.a = a
-            self.b = b
-
     # Build a schema that does not include the field 'b', to test that it is not serialized
     schema = core_schema.dataclass_schema(
         Foo,
         core_schema.dataclass_args_schema(
             'Foo', [core_schema.dataclass_field(name='a', schema=core_schema.str_schema())]
         ),
+        ['a'],
     )
     Foo.__pydantic_validator__ = SchemaValidator(schema)
     Foo.__pydantic_serializer__ = SchemaSerializer(schema)
@@ -473,3 +491,79 @@ def test_any_model():
         assert j == b'{"a":"hello"}'
 
     assert s.to_python(Foo(a='hello', b=b'more'), exclude={'a'}) == IsStrictDict()
+    assert s.to_json(Foo(a='hello', b=b'more'), exclude={'a'}) == b'{}'
+
+
+def test_dataclass_classvar(any_serializer):
+    @dataclasses.dataclass
+    class Foo:
+        a: int
+        b: str
+        c: ClassVar[int] = 1
+
+    foo = Foo(1, 'a')
+    assert any_serializer.to_python(foo) == IsStrictDict(a=1, b='a')
+    assert any_serializer.to_json(foo) == b'{"a":1,"b":"a"}'
+
+    @dataclasses.dataclass
+    class Foo2(Foo):
+        pass
+
+    foo2 = Foo2(2, 'b')
+    assert any_serializer.to_python(foo2) == IsStrictDict(a=2, b='b')
+    assert any_serializer.to_json(foo2) == b'{"a":2,"b":"b"}'
+
+
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='slots are only supported for dataclasses in Python >= 3.10')
+def test_dataclass_slots(any_serializer):
+    @dataclasses.dataclass(slots=True)
+    class Foo:
+        a: int
+        b: str
+
+    foo = Foo(1, 'a')
+    assert any_serializer.to_python(foo) == IsStrictDict(a=1, b='a')
+    assert any_serializer.to_json(foo) == b'{"a":1,"b":"a"}'
+
+    @dataclasses.dataclass(slots=True)
+    class Foo2(Foo):
+        pass
+
+    foo2 = Foo2(2, 'b')
+    assert any_serializer.to_python(foo2) == IsStrictDict(a=2, b='b')
+    assert any_serializer.to_json(foo2) == b'{"a":2,"b":"b"}'
+
+
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='slots are only supported for dataclasses in Python >= 3.10')
+def test_dataclass_slots_init_vars(any_serializer):
+    @dataclasses.dataclass(slots=True)
+    class Foo:
+        a: int
+        b: str
+        c: dataclasses.InitVar[int]
+        d: ClassVar[int] = 42
+
+    foo = Foo(1, 'a', 42)
+    assert any_serializer.to_python(foo) == IsStrictDict(a=1, b='a')
+    assert any_serializer.to_json(foo) == b'{"a":1,"b":"a"}'
+
+
+@pytest.mark.skipif(sys.version_info < (3, 10), reason='slots are only supported for dataclasses in Python > 3.10')
+def test_slots_mixed(any_serializer):
+    @dataclasses.dataclass(slots=True)
+    class Model:
+        x: int
+        y: dataclasses.InitVar[str]
+        z: ClassVar[str] = 'z-classvar'
+
+    @dataclasses.dataclass
+    class SubModel(Model):
+        x2: int
+        y2: dataclasses.InitVar[str]
+        z2: ClassVar[str] = 'z2-classvar'
+
+    dc = SubModel(x=1, y='a', x2=2, y2='b')
+    assert dataclasses.asdict(dc) == {'x': 1, 'x2': 2}
+
+    assert any_serializer.to_python(dc) == {'x': 1, 'x2': 2}
+    assert any_serializer.to_json(dc) == b'{"x":1,"x2":2}'
