@@ -180,16 +180,17 @@ all_errors = [
     ('json_invalid', 'Invalid JSON: foobar', {'error': 'foobar'}),
     ('json_type', 'JSON input should be string, bytes or bytearray', None),
     ('recursion_loop', 'Recursion error - cyclic reference detected', None),
-    ('dict_attributes_type', 'Input should be a valid dictionary or instance to extract fields from', None),
+    ('model_type', 'Input should be a valid dictionary or instance of Foobar', {'class_name': 'Foobar'}),
+    ('model_attributes_type', 'Input should be a valid dictionary or object to extract fields from', None),
+    ('dataclass_exact_type', 'Input should be an instance of Foobar', {'class_name': 'Foobar'}),
+    ('dataclass_type', 'Input should be a dictionary or an instance of Foobar', {'class_name': 'Foobar'}),
     ('missing', 'Field required', None),
     ('frozen_field', 'Field is frozen', None),
     ('frozen_instance', 'Instance is frozen', None),
     ('extra_forbidden', 'Extra inputs are not permitted', None),
     ('invalid_key', 'Keys should be strings', None),
     ('get_attribute_error', 'Error extracting attribute: foo', {'error': 'foo'}),
-    ('model_class_type', 'Input should be an instance of foo', {'class_name': 'foo'}),
     ('none_required', 'Input should be None', None),
-    ('bool', 'Input should be a valid boolean', None),
     ('greater_than', 'Input should be greater than 42.1', {'gt': 42.1}),
     ('greater_than', 'Input should be greater than 42.1', {'gt': '42.1'}),
     ('greater_than', 'Input should be greater than 2020-01-01', {'gt': '2020-01-01'}),
@@ -232,7 +233,7 @@ all_errors = [
     ('less_than', 'Input should be less than 42.1', {'lt': 42.1}),
     ('less_than_equal', 'Input should be less than or equal to 42.1', {'le': 42.1}),
     ('float_type', 'Input should be a valid number', None),
-    ('float_parsing', 'Input should be a valid number, unable to parse string as an number', None),
+    ('float_parsing', 'Input should be a valid number, unable to parse string as a number', None),
     ('bytes_type', 'Input should be a valid bytes', None),
     ('bytes_too_short', 'Data should have at least 42 bytes', {'min_length': 42}),
     ('bytes_too_long', 'Data should have at most 42 bytes', {'max_length': 42}),
@@ -275,7 +276,6 @@ all_errors = [
     ('unexpected_positional_argument', 'Unexpected positional argument', None),
     ('missing_positional_only_argument', 'Missing required positional only argument', None),
     ('multiple_argument_values', 'Got multiple values for argument', None),
-    ('dataclass_type', 'Input should be a dictionary or an instance of Foobar', {'dataclass_name': 'Foobar'}),
     ('url_type', 'URL input should be a string or URL', None),
     ('url_parsing', 'Input should be a valid URL, Foobar', {'error': 'Foobar'}),
     ('url_syntax_violation', 'Input violated strict URL syntax rules, Foobar', {'error': 'Foobar'}),
@@ -403,7 +403,7 @@ def test_all_errors():
     error_types = [e['type'] for e in errors]
     if error_types != list(core_schema.ErrorType.__args__):
         literal = ''.join(f'\n    {e!r},' for e in error_types)
-        print(f'python code (end of pydantic_core/core_schema.py):\n\nErrorType = Literal[{literal}\n]')
+        print(f'python code (end of python/pydantic_core/core_schema.py):\n\nErrorType = Literal[{literal}\n]')
         pytest.fail('core_schema.ErrorType needs to be updated')
 
 
