@@ -1,3 +1,4 @@
+import dataclasses
 import re
 from datetime import date
 from typing import Any
@@ -16,7 +17,13 @@ def make_5():
 
 
 class MyModel:
-    __slots__ = '__dict__', '__pydantic_extra__', '__pydantic_fields_set__'
+    __slots__ = '__dict__', '__pydantic_fields_set__', '__pydantic_extra__', '__pydantic_private__'
+
+
+@dataclasses.dataclass
+class MyDataclass:
+    x: int
+    y: str
 
 
 def ids_function(val):
@@ -248,9 +255,13 @@ all_schema_functions = [
     ),
     (
         core_schema.dataclass_schema,
-        # MyModel should be a dataclass, but I'm being lazy here
-        args(MyModel, {'type': 'int'}),
-        {'type': 'dataclass', 'schema': {'type': 'int'}, 'cls': MyModel},
+        args(MyDataclass, {'type': 'int'}, ['foobar']),
+        {'type': 'dataclass', 'schema': {'type': 'int'}, 'fields': ['foobar'], 'cls': MyDataclass},
+    ),
+    (
+        core_schema.dataclass_schema,
+        args(MyDataclass, {'type': 'int'}, ['foobar'], slots=True),
+        {'type': 'dataclass', 'schema': {'type': 'int'}, 'fields': ['foobar'], 'cls': MyDataclass, 'slots': True},
     ),
 ]
 
@@ -306,12 +317,12 @@ def repr_function(value, _info):
     return repr(value)
 
 
-@pytest.mark.parametrize('json_return_type', core_schema.JsonReturnTypes.__args__)
-def test_expected_serialization_types(json_return_type):
+@pytest.mark.parametrize('return_schema', [core_schema.str_schema(), core_schema.int_schema()])
+def test_expected_serialization_types(return_schema):
     SchemaSerializer(
         core_schema.any_schema(
             serialization=core_schema.plain_serializer_function_ser_schema(
-                repr_function, info_arg=True, json_return_type=json_return_type
+                repr_function, info_arg=True, return_schema=return_schema
             )
         )
     )
