@@ -1,6 +1,7 @@
 import pytest
+from dirty_equals import IsFloat, IsInt
 
-from pydantic_core import SchemaError, SchemaValidator, ValidationError
+from pydantic_core import SchemaError, SchemaValidator, ValidationError, __version__, core_schema
 
 from ..conftest import plain_repr
 
@@ -62,11 +63,10 @@ class TestModelClass:
                         'type': 'model',
                         'cls': self.ModelA,
                         'schema': {
-                            'type': 'typed-dict',
-                            'return_fields_set': True,
+                            'type': 'model-fields',
                             'fields': {
-                                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
-                                'b': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                'a': {'type': 'model-field', 'schema': {'type': 'int'}},
+                                'b': {'type': 'model-field', 'schema': {'type': 'str'}},
                             },
                         },
                     },
@@ -74,11 +74,10 @@ class TestModelClass:
                         'type': 'model',
                         'cls': self.ModelB,
                         'schema': {
-                            'type': 'typed-dict',
-                            'return_fields_set': True,
+                            'type': 'model-fields',
                             'fields': {
-                                'c': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
-                                'd': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                'c': {'type': 'model-field', 'schema': {'type': 'int'}},
+                                'd': {'type': 'model-field', 'schema': {'type': 'str'}},
                             },
                         },
                     },
@@ -108,7 +107,7 @@ class TestModelClass:
     def test_error(self, schema_validator: SchemaValidator):
         with pytest.raises(ValidationError) as exc_info:
             schema_validator.validate_python({'a': 2})
-        assert exc_info.value.errors() == [
+        assert exc_info.value.errors(include_url=False) == [
             {'type': 'missing', 'loc': ('ModelA', 'b'), 'msg': 'Field required', 'input': {'a': 2}},
             {'type': 'missing', 'loc': ('ModelB', 'c'), 'msg': 'Field required', 'input': {'a': 2}},
             {'type': 'missing', 'loc': ('ModelB', 'd'), 'msg': 'Field required', 'input': {'a': 2}},
@@ -132,11 +131,10 @@ class TestModelClassSimilar:
                         'type': 'model',
                         'cls': self.ModelA,
                         'schema': {
-                            'type': 'typed-dict',
-                            'return_fields_set': True,
+                            'type': 'model-fields',
                             'fields': {
-                                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
-                                'b': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                'a': {'type': 'model-field', 'schema': {'type': 'int'}},
+                                'b': {'type': 'model-field', 'schema': {'type': 'str'}},
                             },
                         },
                     },
@@ -144,13 +142,12 @@ class TestModelClassSimilar:
                         'type': 'model',
                         'cls': self.ModelB,
                         'schema': {
-                            'type': 'typed-dict',
-                            'return_fields_set': True,
+                            'type': 'model-fields',
                             'fields': {
-                                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
-                                'b': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                'a': {'type': 'model-field', 'schema': {'type': 'int'}},
+                                'b': {'type': 'model-field', 'schema': {'type': 'str'}},
                                 'c': {
-                                    'type': 'typed-dict-field',
+                                    'type': 'model-field',
                                     'schema': {'type': 'default', 'schema': {'type': 'float'}, 'default': 1.0},
                                 },
                             },
@@ -193,7 +190,7 @@ def test_nullable_via_union():
     assert v.validate_python(1) == 1
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python('hello')
-    assert exc_info.value.errors() == [
+    assert exc_info.value.errors(include_url=False) == [
         {'type': 'none_required', 'loc': ('none',), 'msg': 'Input should be None', 'input': 'hello'},
         {
             'type': 'int_parsing',
@@ -219,7 +216,7 @@ def test_union_list_bool_int():
     assert v.validate_python(['1', '0']) == [1, 0]
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python([3, 'true'])
-    assert exc_info.value.errors() == [
+    assert exc_info.value.errors(include_url=False) == [
         {
             'type': 'bool_parsing',
             'loc': ('list[bool]', 0),
@@ -241,8 +238,9 @@ def test_no_choices():
 
     assert str(exc_info.value) == (
         'Invalid Schema:\n'
-        'union -> choices\n'
-        "  Field required [type=missing, input_value={'type': 'union'}, input_type=dict]"
+        'union.choices\n'
+        "  Field required [type=missing, input_value={'type': 'union'}, input_type=dict]\n"
+        f'    For further information visit https://errors.pydantic.dev/{__version__}/v/missing'
     )
     assert exc_info.value.error_count() == 1
     assert exc_info.value.errors() == [
@@ -258,7 +256,7 @@ def test_empty_choices():
 
 def test_one_choice():
     v = SchemaValidator({'type': 'union', 'choices': [{'type': 'str'}]})
-    assert plain_repr(v) == 'SchemaValidator(title="str",validator=Str(StrValidator{strict:false}),slots=[])'
+    assert plain_repr(v) == 'SchemaValidator(title="str",validator=Str(StrValidator{strict:false}),definitions=[])'
     assert v.validate_python('hello') == 'hello'
 
 
@@ -270,7 +268,7 @@ def test_strict_union():
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python('123')
 
-    assert exc_info.value.errors() == [
+    assert exc_info.value.errors(include_url=False) == [
         {'type': 'bool_type', 'loc': ('bool',), 'msg': 'Input should be a valid boolean', 'input': '123'},
         {'type': 'int_type', 'loc': ('int',), 'msg': 'Input should be a valid integer', 'input': '123'},
     ]
@@ -289,8 +287,8 @@ def test_custom_error():
     assert v.validate_python(b'hello') == b'hello'
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(123)
-    # insert_assert(exc_info.value.errors())
-    assert exc_info.value.errors() == [
+    # insert_assert(exc_info.value.errors(include_url=False))
+    assert exc_info.value.errors(include_url=False) == [
         {'type': 'my_error', 'loc': (), 'msg': 'Input should be a string or bytes', 'input': 123}
     ]
 
@@ -303,8 +301,8 @@ def test_custom_error_type():
     assert v.validate_python(b'hello') == b'hello'
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(123)
-    # insert_assert(exc_info.value.errors())
-    assert exc_info.value.errors() == [
+    # insert_assert(exc_info.value.errors(include_url=False))
+    assert exc_info.value.errors(include_url=False) == [
         {'type': 'string_type', 'loc': (), 'msg': 'Input should be a valid string', 'input': 123}
     ]
 
@@ -322,7 +320,94 @@ def test_custom_error_type_context():
     assert v.validate_python(b'hello') == b'hello'
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(123)
-    # insert_assert(exc_info.value.errors())
-    assert exc_info.value.errors() == [
+    # insert_assert(exc_info.value.errors(include_url=False))
+    assert exc_info.value.errors(include_url=False) == [
         {'type': 'less_than', 'loc': (), 'msg': 'Input should be less than 42', 'input': 123, 'ctx': {'lt': 42.0}}
     ]
+
+
+def test_dirty_behaviour():
+    """
+    Check dirty-equals does what we expect.
+    """
+
+    assert 1 == IsInt(approx=1, delta=0)
+    assert 1.0 != IsInt(approx=1, delta=0)
+    assert 1 != IsFloat(approx=1, delta=0)
+    assert 1.0 == IsFloat(approx=1, delta=0)
+
+
+def test_int_float():
+    v = SchemaValidator(core_schema.union_schema([core_schema.int_schema(), core_schema.float_schema()]))
+    assert 'strict_required:true' in plain_repr(v)
+    assert 'ultra_strict_required:true' in plain_repr(v)  # since "float" schema has ultra-strict behaviour
+
+    assert v.validate_python(1) == IsInt(approx=1, delta=0)
+    assert v.validate_json('1') == IsInt(approx=1, delta=0)
+    assert v.validate_python(1.0) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1.0') == IsFloat(approx=1, delta=0)
+
+    v = SchemaValidator(core_schema.union_schema([core_schema.float_schema(), core_schema.int_schema()]))
+    assert v.validate_python(1) == IsInt(approx=1, delta=0)
+    assert v.validate_json('1') == IsInt(approx=1, delta=0)
+    assert v.validate_python(1.0) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1.0') == IsFloat(approx=1, delta=0)
+
+
+def test_str_float():
+    v = SchemaValidator(core_schema.union_schema([core_schema.str_schema(), core_schema.float_schema()]))
+
+    assert v.validate_python(1) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1') == IsFloat(approx=1, delta=0)
+    assert v.validate_python(1.0) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1.0') == IsFloat(approx=1, delta=0)
+
+    assert v.validate_python('1.0') == '1.0'
+    assert v.validate_python('1') == '1'
+    assert v.validate_json('"1.0"') == '1.0'
+    assert v.validate_json('"1"') == '1'
+
+    v = SchemaValidator(core_schema.union_schema([core_schema.float_schema(), core_schema.str_schema()]))
+    assert v.validate_python(1) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1') == IsFloat(approx=1, delta=0)
+    assert v.validate_python(1.0) == IsFloat(approx=1, delta=0)
+    assert v.validate_json('1.0') == IsFloat(approx=1, delta=0)
+
+    assert v.validate_python('1.0') == '1.0'
+    assert v.validate_python('1') == '1'
+    assert v.validate_json('"1.0"') == '1.0'
+    assert v.validate_json('"1"') == '1'
+
+
+def test_strict_check():
+    v = SchemaValidator(core_schema.union_schema([core_schema.int_schema(), core_schema.json_schema()]))
+    assert 'strict_required:true' in plain_repr(v)
+    assert 'ultra_strict_required:false' in plain_repr(v)
+
+
+def test_no_strict_check():
+    v = SchemaValidator(core_schema.union_schema([core_schema.is_instance_schema(int), core_schema.json_schema()]))
+    assert 'strict_required:false' in plain_repr(v)
+    assert 'ultra_strict_required:false' in plain_repr(v)
+
+    assert v.validate_python(123) == 123
+    assert v.validate_python('[1, 2, 3]') == [1, 2, 3]
+
+
+def test_strict_reference():
+    v = SchemaValidator(
+        core_schema.tuple_positional_schema(
+            [
+                core_schema.float_schema(),
+                core_schema.union_schema(
+                    [core_schema.int_schema(), core_schema.definition_reference_schema('tuple-ref')]
+                ),
+            ],
+            ref='tuple-ref',
+        )
+    )
+    assert 'strict_required:true' in plain_repr(v)
+    assert 'ultra_strict_required:true' in plain_repr(v)  # since "float" schema has ultra-strict behaviour
+
+    assert repr(v.validate_python((1, 2))) == '(1.0, 2)'
+    assert repr(v.validate_python((1.0, (2.0, 3)))) == '(1.0, (2.0, 3))'
